[−][src]Crate optlib
The crate for global optimization algorithms. The crate uses common traits for easy switch between algorithms.
Modules
| genetic | The module with genetic algorithm implementation. |
| particleswarm | |
| tools |
Structs
| GoalFromFunction | Struct to convert (wrap) function to |
Traits
| Agent | The trait for single point in search space. The trait used with |
| AgentsState | The trait for algotithms where use agents (genetic algorithm, partical swarm algorithm etc). |
| AlgorithmState | The trait for a struct with information about current algorithm state. For example: population for genetic algorithm, swarm for particle swarm algorithm etc |
| Goal | The trait for the goal function. |
| IterativeOptimizer | The trait for iterative algorithms. |
| Optimizer | Common Optimizer trait. |