[−][src]Module optlib::genetic::selection
The module with selection algorithms.
The algoritms must kill individuals which does not go to
next generation. The algorithm must call kill() method for such individuals.
Modules
| vec_float | The module with selection algorithms for type chromosomes of Vec |
Structs
| KillFitnessNaN | Kill individuals if value of theirs fitness (goal function) is NaN. Returns count of killed individuals. |
| LimitPopulation |
Functions
| kill_worst | Function to kill worst individuals in population.
|