CheckChromoInterval

Struct CheckChromoInterval 

pub struct CheckChromoInterval<G: Float> { /* private fields */ }
Kill individuals if theirs gene does not lie in the specified intevals.

G - type of gene. Returns count of the killed individuals.

Implementations

Source

impl<G: Float> CheckChromoInterval<G>

pub fn new(intervals: Vec<(G, G)>) -> Self

Constructor.

Parameters
  • intervals - allowed interval for every gene. Count of the genes and count of the interval must be equal.