[−][src]Module optlib::genetic::stopchecker
The module with structs for StopChecker traits.
Structs
| CompositeAll | Stop genetic algorithm if ALL stop checkers returns true |
| CompositeAny | Stop genetic algorithm if ANY of stop checker returns true |
| GoalNotChange | Genetic algorithm will be stopped if goal function of the best individual does not change. |
| MaxIterations | Genetic algorithm will be stopped after specified generation (iteration). |
| Threshold | Stop genetic algorithm if value of the goal function less of than threshold. |