[−][src]Struct optlib::genetic::stopchecker::GoalNotChange
Genetic algorithm will be stopped if goal function of the best individual does not change.
Methods
impl GoalNotChange[src]
pub fn new(max_iter: usize, delta: f64) -> Self[src]
Constructor.
Parameters
max_iter- how many iterations (generations) the value of goal function of the best individual may not change.delta- small value. The change of goal function is not considered if the change less ofdelta.