pub struct RandomTeleport<T: Float + SampleUniform> { /* private fields */ }Expand description
The struct to move particle to random position with given probability
Implementations
Sourceimpl<T: Float + SampleUniform> RandomTeleport<T>
impl<T: Float + SampleUniform> RandomTeleport<T>
Sourcepub fn new(intervals: Vec<(T, T)>, probability: f32) -> Self
pub fn new(intervals: Vec<(T, T)>, probability: f32) -> Self
Constructor.
Parameters
intervals - intervals - vector of tuples. Size of the vector must be equal to dimension. The first value in tuple is minimum coordinate, the second value is maximum coordinate.
probability - probability of particle teleportation. Must be in the range [0, 1].