The module with most usable algorithms of crossing for various types.
The module contains struct which implements the Cross trait and functions to cross
chromosomes various types.
Structs
- Cross
Bitwise - Bitwise cross. Use single point crossing. Result of cross is single child.
- Cross
Mean - Child chromosome is arithmetic mean of parent chromosomes. Result of cross is single child. The chromosomes must be numeric type.
- Float
Cross Exp - Bitwise cross for float type chromosomes. Exponent and mantissa will be crossed independently. Use single point crossing. The sign is taken from one of parents at random.
- Float
Cross Geometric Mean - For float type chromosomes (f32, f64). Child chromosome is geometric mean of parent chromosomes. Result of cross is single child.
- VecCross
AllGenes - Struct to cross all genes (
G- type of genes) in chromosome of type Vec.