[−][src]Struct optlib::genetic::selection::vec_float::CheckChromoInterval
Kill individuals if theirs gene does not lie in the specified intevals.
G - type of gene.
Returns count of the killed individuals.
Methods
impl<G: Float> CheckChromoInterval<G>[src]
pub fn new(intervals: Vec<(G, G)>) -> Self[src]
Constructor.
Parameters
intervals- allowed interval for every gene. Count of the genes and count of the interval must be equal.