Structs
- Composite
All - Stop the algorithm if ALL stop checkers returns true
- Composite
Any - Stop the algorithm if ANY of stop checker returns true
- Goal
NotChange - The algorithm will be stopped if the best goal function does not change.
- MaxIterations
- The algorithm will be stopped after specified iteration.
- Threshold
- Stop the algorithm if value of the goal function less of than threshold.
Traits
- Stop
Checker - The trait with break criterion optimization algorithm.